from pydantic import BaseModel, Field
from typing import Optional


class InvoiceStatusChange(BaseModel):
    status: str


class InvoiceResponse(BaseModel):
    lago_id: str
    sequential_id: int
    issuing_date: Optional[str]
    invoice_type: str
    status: str
    amount_cents: int
    amount_currency: str
    vat_amount_cents: int
    vat_amount_currency: str
    total_amount_cents: int
    total_amount_currency: str
    file_url: Optional[str]



from pydantic import BaseModel, Field
from typing import Optional


class Organization(BaseModel):
    webhook_url: Optional[str]
    vat_rate: Optional[float]
    country: Optional[str]
    address_line1: Optional[str]
    address_line2: Optional[str]
    state: Optional[str]
    zipcode: Optional[str]
    email: Optional[str]
    city: Optional[str]
    legal_name: Optional[str]
    legal_number: Optional[str]
    invoice_footer: Optional[str]


class OrganizationResponse(BaseModel):
    name: str
    created_at: str
    webhook_url: Optional[str]
    vat_rate: Optional[float]
    country: Optional[str]
    address_line1: Optional[str]
    address_line2: Optional[str]
    state: Optional[str]
    zipcode: Optional[str]
    email: Optional[str]
    city: Optional[str]
    legal_name: Optional[str]
    legal_number: Optional[str]
    invoice_footer: Optional[str]



from pydantic import BaseModel, Field
from typing import Optional


class BillableMetric(BaseModel):
    name: Optional[str]
    code: Optional[str]
    description: Optional[str]
    aggregation_type: Optional[str]
    field_name: Optional[str]


class BillableMetricResponse(BaseModel):
    lago_id: str
    name: str
    code: str
    description: Optional[str]
    aggregation_type: Optional[str]
    field_name: Optional[str]
    created_at: str
